#include "filtertableview.h"


FilterTableView::FilterTableView(QWidget *parent) :
    QTableView(parent)
{
    _timer = new QTimer(this);
    _filterLayout = new QHBoxLayout;
    horizontalHeader()->setLayout(_filterLayout);
    horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeMode::Stretch);
}


void FilterTableView::filterLayoutAddWidgets()
{
    if(!_editColumns.isEmpty())
        for(int i(0); i < _editColumns.size(); ++i)
            _filterLayout->addWidget(createLineEditForColumn(_editColumns[i]));
    else
        for(int i(0); i < _model->columnCount(); ++i)
            _filterLayout->addWidget(createLineEditForColumn(i));
}

QWidget *FilterTableView::createLineEditForColumn(const int column)
{
    QLineEdit *widget = new QLineEdit();
    if(_regexpColumns.contains(column))
        widget->setValidator(new QRegExpValidator(QRegExp(_regexpColumns.value(column))));

    connect(widget, &QLineEdit::textChanged, [this, column](const QString text)
    {
        _timer->start(500);
        connect(_timer, &QTimer::timeout, [this, column, text](){
            emit filterTViewTextChanged(column, text);});
    });
    return widget;
}

void FilterTableView::setRegExpForColumn(QMap<int, QString> regexpColumns)
{
    _regexpColumns = regexpColumns;
}

void FilterTableView::setEditColumns(QVector<int> editColumns)
{
    _editColumns = editColumns;
}

void FilterTableView::setModel(QAbstractItemModel *model)
{
    _model = model;
    QTableView::setModel(model);
    filterLayoutAddWidgets();
}

